****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_macros.sas
*
* Created (mm/dd/yyyy): 12/19/2014
* Last modified: 12/19/2014
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   These are utility macros that are used to import files and verify if an dataset contains observations.
*
*  Program inputs:
*
*  Program outputs:
*
*  PARAMETERS:
*	ISDATA(dataset=)
*		dataset = Name of a dataset for which we want to verify if it contains observations
*
*	IMPORTFILES(var=)
*		var = Name of a dataset that we want to import
*
*  Programming Notes:
*
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO:
*  Mini-Sentinel Coordinating Center
*  info@mini-sentinel.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG:
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*	v2.0  02/27/2017  Y.V.          Added code to test for a view and set nobs=-1 for a view.     
***************************************************************************************************;
 /*Macro to determine whether a dataset is empty or not;*/
%MACRO ISDATA(dataset=);

%PUT =====> MACRO CALLED: ms_macros v1.0 => ISDATA;

	%GLOBAL NOBS;
	%let NOBS=0;
	%if %sysfunc(exist(&dataset.))=1  and %LENGTH(&dataset.) ne 0 %then %do;
		data _null_;
		dsid=open("&dataset.");
		call symputx("NOBS",attrn(dsid,"NLOBS"));
		run;
	%end;

%IF  %sysfunc(exist(&dataset., view))=1 OR 	%sysfunc(exist(&dataset., ACCESS))=1
 %THEN 	%let NOBS=-1;

%PUT Dataset &dataset. : NOBS=&NOBS.;

%put NOTE: ********END OF MACRO: ms_macros v1.0 => ISDATA ********;

%MEND ISDATA;

%MACRO IMPORTFILES(var=);

%PUT =====> MACRO CALLED: ms_macros v1.0 => IMPORTFILES;

	%IF %INDEX(%UPCASE("&VAR."),CPORT) %THEN %DO;
		proc cimport infile="&infolder.&VAR." library=infolder memtype=data;
		run;
	%END;

%put NOTE: ********END OF MACRO: ms_macros v1.0 => IMPORTFILES ********;

%MEND IMPORTFILES;

%MACRO VAREXIST(DS,VAR);

%PUT =====> MACRO CALLED: ms_macros v1.0 => VAREXIST;

%GLOBAL VAREXIST;
%LET VAREXIST=0;
%LET DSID = %SYSFUNC(OPEN(&DS));
%IF (&DSID) %THEN %DO;
    %IF %SYSFUNC(VARNUM(&DSID,&VAR)) %THEN %LET VAREXIST=1;
    %LET RC = %SYSFUNC(CLOSE(&DSID));
%END;

%put NOTE: ********END OF MACRO: ms_macros v1.0 => VAREXIST ********;

%MEND VAREXIST;

 %macro ms_check_path(path) ;
	%local ln lc d_exist ;
	%let ln = %length(&path) ;
	%if &ln eq 0 %then %do ;
		 %put The parameter path must be non-missing. ;
		 %abort cancel ;
	%end ;
	%else %if &ln > 0 %then %do ;
	   %let path = %sysfunc(translate(&path, %str(/), %str(\))) ;
	   %let lc = %substr(&path, &ln) ;
	   %if "&lc" ne "/" %then %do ;
	   	  %let path = &path./ ;
	   %end ;	
	   %let d_exist = %ms_dirCheck(&path) ;
     %if &d_exist eq 0 %then %do ;
        %put Path &path does not exist;
        %abort cancel;
     %end ;	
	%end ;
	&path 	 /* returns value to calling enivornment, like a function */
%mend ms_check_path ;


%macro ms_dirCheck(dir) ;
  /* Original Author: Adrien Vallee */	
  /* Original Source: http://www.sascommunity.org/wiki/Tips:Check_if_a_directory_exists */
  /* Terms of Use: http://www.sascommunity.org/wiki/sasCommunity:Terms_of_Use */

   %if %length(&dir) eq 0 %then %do ;
   	  %put The parameter dir must be non-missing.  ;
   	  %abort cancel ;
   %end ;
   %local rc fileref return ;
   %let rc = %sysfunc(filename(fileref,&dir)) ;
   %let return = %sysfunc(fexist(&fileref)) ;
   &return  /* returns value to calling enivornment, like a function */
   %let rc = %sysfunc(filename(fileref)) ;
%mend ms_dirCheck;

